## Version 0.0.74

This new version includes an update to the pip installation in the test workflow and the addition of a new dependency, beartype==0.15.0.

### New Features

- Added beartype==0.15.0 to the list of dependencies in pyproject.toml (8c4db1) (Eric Ma)

### Bug Fixes

- Updated pip installation in the test-pypi-package.yaml workflow to use the `python -m pip install` command instead of `pipx` to ensure the correct version of pip is used for installing the `llamabot[all]` package (2e860a) (Eric Ma)

### Deprecations

- None in this release.
